(*
    Turbo/Borland Pascal interface to TGX library
    Copyright (c) 1993-2003,2004 by Alessandro Scotti
    http://www.ascotti.org/

    Target: real, protected.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*)
unit Tgx;
interface

const
  MAXCHARHEIGHT = 16;
  MAXTGXWINSIZE = 256;
type
(* TGX character *)
  TTgxChar      = record
    Code        : byte;
    Attr        : byte;
    Data        : array[ 0..MAXCHARHEIGHT-1 ] of byte;
  end;
  PTgxChar      = ^TTgxChar;
  TTgxCharArray = array[ 0..MAXTGXWINSIZE-1 ] of TTgxChar;
  PTgxCharArray = ^TTgxCharArray;
(* TGX window *)
  TTgxWindow    = record
    X, Y        : integer;
    Width       : word;
    Height      : word;
    PixelWidth  : word;
    PixelHeight : word;
    Size        : word;
    Chars       : PTgxCharArray;
    Font        : byte;
    Reserved    : array[ 1..1 ] of byte;
  end;
  PTgxWindow    = ^TTgxWindow;

  PChar         = ^char;

function tgxInit: integer;
function tgxDone: integer;
function tgxShow( P: PTgxWindow; Page: byte ): integer;
function tgxClear( P: PTgxWindow ): integer;
function tgxRefresh( P: PTgxWindow ): integer;
function tgxGetPixel( P: PTgxWindow; X, Y: word ): integer;
function tgxSetPixel( P: PTgxWindow; X, Y: word ): integer;
function tgxResetPixel( P: PTgxWindow; X, Y: word ): integer;
function tgxGrabChar( C: char; P: PTgxChar ): integer;
function tgxInitWindow( P: PTgxWindow; X, Y: integer; W, H: word; A: byte; S: PChar ): integer;
function tgxDoneWindow( P: PTgxWindow ): integer;
function tgxWaitRetrace: integer;

function tgxCreate( X, Y: integer; W, H: word; A: byte; S: PChar ): PTgxWindow;
function tgxDestroy( P: PTgxWindow ): integer;

implementation

function tgxInit: integer;                                      external;
function tgxDone: integer;                                      external;
function tgxShow( P: PTgxWindow; Page: byte ): integer;         external;
function tgxClear( P: PTgxWindow ): integer;                    external;
function tgxRefresh( P: PTgxWindow ): integer;                  external;
function tgxSetPixel( P: PTgxWindow; X, Y: word ): integer;     external;
function tgxGetPixel( P: PTgxWindow; X, Y: word ): integer;     external;
function tgxResetPixel( P: PTgxWindow; X, Y: word ): integer;   external;
function tgxGrabChar( C: char; P: PTgxChar ): integer;          external;
function tgxInitWindow;                                         external;
function tgxDoneWindow;                                         external;
function tgxWaitRetrace: integer;                               external;
{$L TGX}

function tgxCreate;
var
  P     : PTgxWindow;
  Size  : word;
begin
  (* Check parameters *)
  tgxCreate := NIL;
  Size := W*H;
  if( Size > MAXTGXWINSIZE ) then
    Exit;
  Size := Size*SizeOf(TTgxChar)+SizeOf(TTgxWindow);
  if( MaxAvail < Size ) then
    Exit;

  (* Allocate memory for the window and initialize data *)
  GetMem( P, Size );
  tgxInitWindow( P, X, Y, W, H, A, S );
  tgxClear( P );

  (* Return a pointer to the window *)
  tgxCreate := P;
end;

function tgxDestroy;
begin
  tgxDoneWindow( P );
  FreeMem( P, P^.Size*SizeOf(TTgxChar)+SizeOf(TTgxWindow) );
  tgxDestroy := 0;
end;

end.
